@@ -9,9 +9,8 @@ import argparse
 import sys
 from webdriver_manager.firefox import GeckoDriverManager
 from selenium.webdriver.firefox.service import Service as FirefoxService
-from selenium.webdriver.chrome.service import Service as ChromiumService
+from selenium.webdriver.chrome.service import Service as ChromeService
 from webdriver_manager.chrome import ChromeDriverManager
-from webdriver_manager.core.utils import ChromeType
 from prettytable import PrettyTable, ALL
 from typing import List
 from decimal import Decimal
@@ -674,7 +673,7 @@ def trends_google_play(gl, hl):
         browser = webdriver.Firefox(service = FirefoxService(GeckoDriverManager().install()), options=options)
     except Exception as e:
         print ("Використовую ядро Chromium!")
-        browser = webdriver.Chrome(service=ChromiumService(ChromeDriverManager(chrome_type=ChromeType.CHROMIUM).install()), options=chrome_options)
+        browser = webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()), options=chrome_options)
     browser.implicitly_wait(10)
     browser.maximize_window()
 
